@@ -7,7 +7,7 @@ from matplotlib import pyplot as plt
 from torch import optim, nn
 from torchvision import transforms
 
-from siamese import FibersSiamese
+from siamese.fibers_siamese import FibersSiamese
 
 
 def match_fibers(distances,cross_check =True,max_distance= np.inf):
